==> shar-3.52.3.tar.gz: shar-3.52.3/shar.h <==
/* Handle so called `shell archives'.
   Copyright (C) 1994 Free Software Foundation, Inc.
  
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.
  
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
  
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#ifdef HAVE_CONFIG_H
#if defined (CONFIG_BROKETS)
/* We use <config.h> instead of "config.h" so that a compilation
   using -I. -I$srcdir will use ./config.h rather than $srcdir/config.h
   (which it would do because it found this file in $srcdir).  */
#include <config.h>
#else
#include "config.h"
#endif
#endif

#define VERSION "3.52.3"

#ifdef __STDC__
#define voidstar void *
#else
#define voidstar char *
#endif

#ifdef PROTOTYPES
#define _(Args) Args
#else
#define _(Args) ()
#endif

#if defined (HAVE_STRING_H) || defined (STDC_HEADERS)
#include <string.h>

/* An ANSI string.h and pre-ANSI memory.h might conflict.  */
#if !defined (STDC_HEADERS) && defined (HAVE_MEMORY_H)
#include <memory.h>
#endif

#else /* not HAVE_STRING_H and not STDC_HEADERS */

#include <strings.h>

#ifndef strchr
#define strchr(String, Char) index ((String), (Char))
#endif

#endif /* not HAVE_STRING_H and not STDC_HEADERS */

#ifdef STDC_HEADERS
#include <stdlib.h>
#else
char *getenv ();
#endif

/* Some systems do not define EXIT_*, even with STDC_HEADERS.  */
#ifndef EXIT_SUCCESS
#define EXIT_SUCCESS 0
#endif
#ifndef EXIT_FAILURE
#define EXIT_FAILURE 1
#endif

/* Other header files.  */

#include <stdio.h>

#include <errno.h>
#ifndef errno
extern int errno;
#endif

#include <sys/types.h>

/* System functions.  Even if we usually avoid declaring them, we cannot
   avoid them all.  */

FILE *fdopen ();
long ftell ();
FILE *popen ();

/* GNU small library functions.  */

char *basename _((const char *));
void error _((int, int, const char *, ...));
char *xgetcwd _((void));
voidstar xmalloc _((size_t));

/* Global functions of the shar package.  */

void copy_file_encoded _((FILE *, FILE *));
char *get_submitter _((char *));

==> shar-4.0.tar.gz: shar-4.0/shar.h <==
/* Handle so called `shell archives'.
   Copyright (C) 1994 Free Software Foundation, Inc.
  
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.
  
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
  
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

/* We use <config.h> instead of "config.h" so that a compilation
   using -I. -I$srcdir will use ./config.h rather than $srcdir/config.h
   (which it would do because it found this file in $srcdir).  */

#ifdef HAVE_CONFIG_H
# ifdef CONFIG_BROKETS
#  include <config.h>
# else
#  include "config.h"
# endif
#endif

#define VERSION "4.0"

#ifdef __STDC__
# define voidstar void *
#else
# define voidstar char *
#endif

#ifdef PROTOTYPES
# define _(Args) Args
#else
# define _(Args) ()
#endif

/* Declare string and memory handling routines.  Take care that an ANSI
   string.h and pre-ANSI memory.h might conflict, and that memory.h and
   strings.h conflict on some systems.  */

#if STDC_HEADERS || HAVE_STRING_H
# include <string.h>
# if !STDC_HEADERS && HAVE_MEMORY_H
#  include <memory.h>
# endif
#else
# include <strings.h>
# ifndef strchr
#  define strchr index
# endif
#endif

#ifdef STDC_HEADERS
# include <stdlib.h>
#else
char *getenv ();
#endif

/* Some systems do not define EXIT_*, even with STDC_HEADERS.  */
#ifndef EXIT_SUCCESS
# define EXIT_SUCCESS 0
#endif
#ifndef EXIT_FAILURE
# define EXIT_FAILURE 1
#endif

/* Other header files.  */

#include <stdio.h>

#include <errno.h>
#ifndef errno
extern int errno;
#endif

#include <sys/types.h>

#ifdef HAVE_SYS_WAIT_H
# include <sys/wait.h>
#endif

/* System functions.  Even if we usually avoid declaring them, we cannot
   avoid them all.  */

#ifdef HAVE_UNISTD_H
# include <unistd.h>
#endif

FILE *fdopen ();
long ftell ();
FILE *popen ();

/* GNU small library functions.  */

char *basename _((const char *));
void error _((int, int, const char *, ...));
char *xgetcwd _((void));
voidstar xmalloc _((size_t));
voidstar xrealloc _((voidstar, size_t));
char *xstrdup _((const char *));

/* Global functions of the shar package.  */

void copy_file_encoded _((FILE *, FILE *));
char *get_submitter _((char *));

/* Debugging the memory allocator.  */

#ifdef WITH_DMALLOC
# define MALLOC_FUNC_CHECK
# include <dmalloc.h>
#endif
